aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/objective-c/tests/InteropTests.h
diff options
context:
space:
mode:
authorGravatar Jorge Canizales <jcanizales@google.com>2015-10-28 15:13:40 -0700
committerGravatar Jorge Canizales <jcanizales@google.com>2015-10-28 15:13:40 -0700
commit2beb88c1fd961cfd697df6c94d6bd72537ddefc9 (patch)
tree76b830c16426156f153cebc558ad0c766944b785 /src/objective-c/tests/InteropTests.h
parent91db5acd5b52a41d7069fd56bf0f6802b6c6e4b7 (diff)
Fix documentation of tests
Diffstat (limited to 'src/objective-c/tests/InteropTests.h')
-rw-r--r--src/objective-c/tests/InteropTests.h16
1 files changed, 11 insertions, 5 deletions
diff --git a/src/objective-c/tests/InteropTests.h b/src/objective-c/tests/InteropTests.h
index 383e3befb4..6d54343b13 100644
--- a/src/objective-c/tests/InteropTests.h
+++ b/src/objective-c/tests/InteropTests.h
@@ -33,11 +33,17 @@
#import <XCTest/XCTest.h>
-// Implements tests as described here:
-// https://github.com/grpc/grpc/blob/master/doc/interop-test-descriptions.md
-
+/**
+ * Implements tests as described here:
+ * https://github.com/grpc/grpc/blob/master/doc/interop-test-descriptions.md
+ *
+ * This is an abstract class that needs to be subclassed. See |+host|.
+ */
@interface InteropTests : XCTestCase
-// Returns nil, and as a consequence all tests of the superclass are skipped.
-// Override in a subclass to perform these tests against a specific address.
+/**
+ * Host to send the RPCs to. The base implementation returns nil, which would make all tests to
+ * fail.
+ * Override in a subclass to perform these tests against a specific address.
+ */
+ (NSString *)host;
@end